/*************************************************************************

  global.c v1.0

    Some global functions and variables.
    global.c is part of the Oankali's GP32 run-time library.

  Copyright (c) 2004 by
  Guillem Reinoso <oankali@nekanium.com>
  www.nekanium.com

  These software is freeware and is provided as is.
  If it doesn't work for you or it makes your PC or GP32 melt down, it's not my
  responsibility.
  If you use it in your programs, cite me please.

**************************************************************************/


#include <gpdef.h>
#include <gpstdlib.h>
#include <gpmem.h>
#include <gpgraphic.h>

#include "global.h"


GPDRAWSURFACE gtSurface[2];
int giSurface;


// Implementations
void GetKeys(int *pressedKeys)
{
  int newKeys;

  if (*pressedKeys != GPC_VK_NONE)
    *pressedKeys = 0x800;
  newKeys = GpKeyGet();
  if ((*pressedKeys == 0x800) && (newKeys == GPC_VK_NONE))
    *pressedKeys = GPC_VK_NONE;
  if (*pressedKeys == GPC_VK_NONE) 
    *pressedKeys = newKeys;
}

void InitGraphics(int depth)
{
  // Initialize graphic mode
  GpGraphicModeSet(depth, NULL);

  // Crea les superficies
  GpLcdSurfaceGet(&gtSurface[0], 0);
  GpLcdSurfaceGet(&gtSurface[1], 1);

  // Register surfaces
  giSurface = 0;
  GpSurfaceSet(&gtSurface[giSurface]);

  // Activates LCD if needed
  if (!(GpLcdStatusGet() & GPC_LCD_ON_BIT))
    GpLcdEnable();

  giSurface = 1;
}

void PushKey()
{
  unsigned int tick;

  tick = GpTickCountGet();
  while (!GpKeyGet());
  while ((GpTickCountGet() - tick) < 200) ;
}

char *Thousands(char *number)
{
  int i, p, d;

  p = gm_lstrlen(number);
  if (p <= 3)
    return number;

  i = 0;
  d = (p - 1) / 3;
  number[p + d] = number[p--];

  while (d)
  {
    number[p + d] = number[p--];
    if (++i % 3 == 0)
    {
      number[p + d] = '.';
      d--;
    }
  }

  return number;
}

void Wait(unsigned int ticks)
{
  unsigned int tick;

  tick = GpTickCountGet();
  while ((GpTickCountGet() - tick) < ticks) ;
}

int WaitKey(unsigned int ticks)
{
  unsigned int tick;

  tick = GpTickCountGet();
  while ((GpTickCountGet() - tick) < ticks)
    if (GpKeyGet())
      return TRUE;

  return FALSE;
}
