/*************************************************************************

  graphics16.h v2.0

    Graphics functions to work in 16 bits for the Game Park GP32.
    graphics16.h is part of the Oankali's GP32 run-time library.

  Copyright (c) 2004,2005 by
  Guillem Reinoso <oankali@nekanium.com>
  www.nekanium.com

  These software is freeware and is provided as is.
  If it doesn't work for you or it makes your PC or GP32 melt down, it's not my
  responsibility.
  If you use it in your programs, cite me please.

  History:
    v1.0
      First public release
    v2.0
      Removed   AddColors(), AddPixel(), AddSmoothedColors(), FillOverlay16(),
                SubPixel(), SubstractColors(), TransBltColored16()
      Added     AddColor16(), BitBlt16() and ReleaseScreenRegion().
                SaveBackScreenRegion(), SubtractColor16(), TransBlt16(),
                TransFade16() and TransFadeMask16().
      Renamed   BitBlt8To16() to BitBltGrayTo16().
      Changed   BitTile16() -> added more paremeters.
      Changed   TransTile16() -> added more paremeters.
      Added     alpha blending lookup table to optimize alpha blending.
                -> InitializeAlphaLUT(), ReleaseAlphaLUT(),
                   gtAlphaLUT, giAlphaLevels and ALT_* constants.
      Optimized BitBltGrayTo16() and OverlayColor16().

**************************************************************************/


#ifndef __graphics16_h__
#define __graphics16_h__

#ifdef __cplusplus
extern "C" {
#endif


#define ALT_32LEVELS   0
#define ALT_16LEVELS   1
#define ALT_8LEVELS    2
#define ALT_4LEVELS    3


// Global variables
extern unsigned char (*gtAlphaLUT)[32][32];  // alpha blending lookup table
extern int giAlphaLevels;                    // precision of the alpha LUT


// Macro definitions
#define CopyBackScreen() \
{\
  gm_memcpy(gtSurface[giSurface].ptbuffer, gtSurface[(giSurface+1) & 0x01].ptbuffer, 320 * 240 * sizeof(unsigned short));\
}

#define RGB(Red, Green, Blue) (((unsigned int) ((Red)  << 11)) + \
                               ((unsigned int) ((Green) << 6)) + \
                               ((unsigned int) ((Blue)  << 1)))

#define GetRGBRed(color)   (((color) >> 11) & 0x1F)
#define GetRGBGreen(color) (((color) >>  6) & 0x1F)
#define GetRGBBlue(color)  (((color) >>  1) & 0x1F)

#define GetPixel(ptgpds, x,  y) (*((unsigned short *)((ptgpds)->ptbuffer) + (x) * 240 + (239 - (y))))

#define PutPixel(ptgpds, x,  y,  c)\
{\
	*((unsigned short *)((ptgpds)->ptbuffer) + (x) * 240 + (239 - (y))) = (c);\
}


// Prototypes
void AddColor16(GPDRAWSURFACE *ptgpds, int dx, int dy, int width, int height, int color);
int  BitBlt16(GPDRAWTAG *gptag, GPDRAWSURFACE *ptgpds, int dx, int dy, int width, int height, unsigned char *bitmap, int bitmapx, int bitmapy, int bitmapWidth, int bitmapHeight);
int  BitBltGrayTo16(GPDRAWTAG *gptag, GPDRAWSURFACE *ptgpds, int dx, int dy, int width, int height, unsigned char *bitmap, int bitmapx, int bitmapy, int bitmapWidth, int bitmapHeight);
int  BitTile16(GPDRAWTAG *gptag, GPDRAWSURFACE *ptgpds, int dx, int dy, int width, int height, unsigned char *bitmap, int bitmapx, int bitmapy, int bitmapWidth, int bitmapHeight, int tileWidth, int tileHeight);
int InitializeAlphaLUT(int alphaLevels, unsigned char (*pAlphaLUT)[32][32]);
void OverlayColor16(GPDRAWSURFACE *ptgpds, int dx, int dy, int width, int height, int color, int intensity); //, unsigned char (*alphaLUT)[32][32], int alphaLevels);
void ReleaseAlphaLUT(void);
void ReleaseScreen(unsigned short *bitmap);
void ReleaseScreenRegion(unsigned short *bitmap);
unsigned short *SaveBackScreen(void);
unsigned short *SaveBackScreenRegion(int x, int y, int width, int height);
unsigned short *SaveScreen(void);
void SubtractColor16(GPDRAWSURFACE *ptgpds, int dx, int dy, int width, int height, int color);
int  TransBlt16(GPDRAWTAG *gptag, GPDRAWSURFACE *ptgpds, int dx, int dy, int width, int height, unsigned char *bitmap, int bitmapx, int bitmapy, int bitmapWidth, int bitmapHeight, unsigned short transColor);
int  TransFade16(GPDRAWTAG *gptag, GPDRAWSURFACE *ptgpds, int dx, int dy, int width, int height, unsigned char *bitmap, int bitmapx, int bitmapy, int bitmapWidth, int bitmapHeight, unsigned short transColor, int opacity);
int  TransFadeMask16(GPDRAWTAG *gptag, GPDRAWSURFACE *ptgpds, int dx, int dy, int width, int height, unsigned char *mask, int maskx, int masky, int maskWidth, int maskHeight, unsigned short color, int opacity);
int  TransTile16(GPDRAWTAG *gptag, GPDRAWSURFACE *ptgpds, int dx, int dy, int width, int height, unsigned char *bitmap, int bitmapx, int bitmapy, int bitmapWidth, int bitmapHeight, int tileWidth, int tileHeight, int transColor);

#ifdef __cplusplus
  }
#endif

#endif /*__graphics16_h__*/
